# info.py
# Model for json return from /info API 
from typing import Optional
from pydantic import BaseModel

"""
Output should be something like...
    "version": "0.10.0-SNAPSHOT",
    "artifactId": "partition-gcp",
    "name": "partition-gcp",
    "groupId": "org.opengroup.osdu",
    "buildTime": "2021-06-21T08:41:50.703Z"
    "branch": "gcp-entv2-stab"
    "commitId": "b2d47532ff4d275cdb208120fcbb0703383a88b2"
    "commitMessage": "MR 4711"
    "buildTime": "2021-06-21T08:41:50.703Z"
    "connectedOuterServices": { 
        "elasticSearch": {
             "version":"..."
        },
        "postgresSql": {
            "version":"..."
        },
        "opa": {
            "version":"..."
        }
    }
}
"""
class InfoBaseModel(BaseModel):
    def __hash__(self):  # make hashable BaseModel subclass
        return hash((type(self),) + tuple(self.__dict__.values()))

class ServiceDetail(InfoBaseModel):
    version: Optional[str] = None

class Services(InfoBaseModel):
    opa: ServiceDetail
    
class InfoOut(InfoBaseModel):
    version: str
    artifactId: Optional[str] = None
    name: Optional[str] = "policy"
    groupId: Optional[str] = None
    buildTime: Optional[str] = None
    branch: Optional[str] = None
    commitId: Optional[str] = None
    commitMessage: Optional[str] = None
    buildTime: Optional[str] = None
    connectedOuterServices: Services