#!/bin/bash

# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Requires the following env variables to be set:
# AWS_REGION
# EKS_CLUSTER_NAME
# AWS_ACCOUNT_ID
# EKS_CLUSTER_MGMT_ROLE
# https://docs.aws.amazon.com/eks/latest/userguide/create-kubeconfig.html

export CLUSTER_ENDPOINT=$(aws eks describe-cluster \
    --region $AWS_REGION \
    --name $EKS_CLUSTER_NAME \
    --query "cluster.endpoint" \
    --output text)

export CERTIFICATE_DATA=$(aws eks describe-cluster \
    --region $AWS_REGION \
    --name $EKS_CLUSTER_NAME \
    --query "cluster.certificateAuthority.data" \
    --output text)

mkdir -p ~/.kube

read -r -d '' KUBECONFIG <<EOF
apiVersion: v1
clusters:
- cluster:
    certificate-authority-data: $CERTIFICATE_DATA
    server: $CLUSTER_ENDPOINT
  name: arn:aws:eks:$AWS_REGION:$AWS_ACCOUNT_ID:cluster/$EKS_CLUSTER_NAME
contexts:
- context:
    cluster: arn:aws:eks:$AWS_REGION:$AWS_ACCOUNT_ID:cluster/$EKS_CLUSTER_NAME
    user: arn:aws:eks:$AWS_REGION:$AWS_ACCOUNT_ID:cluster/$EKS_CLUSTER_NAME
  name: arn:aws:eks:$AWS_REGION:$AWS_ACCOUNT_ID:cluster/$EKS_CLUSTER_NAME
current-context: arn:aws:eks:$AWS_REGION:$AWS_ACCOUNT_ID:cluster/$EKS_CLUSTER_NAME
kind: Config
preferences: {}
users:
- name: arn:aws:eks:$AWS_REGION:$AWS_ACCOUNT_ID:cluster/$EKS_CLUSTER_NAME
  user:
    exec:
      apiVersion: client.authentication.k8s.io/v1beta1
      command: aws
      args:
        - --region
        - $AWS_REGION
        - eks
        - get-token
        - --cluster-name
        - $EKS_CLUSTER_NAME
        - --role-arn
        - $EKS_CLUSTER_MGMT_ROLE

EOF
echo "${KUBECONFIG}" > ~/.kube/config