import os
import tarfile
from jinja2 import Environment, FileSystemLoader, select_autoescape
import argparse


class BootstrapDataPartitionBundles:

    def create_and_upload_dp_bundles(dp_id):
        tar_name = "bundle-{dp}.tar.gz".format(dp=dp_id)
        dataauthz_template_name = "dataauthz_template.rego"
        manifest_template_name = "manifest_template.manifest"
        search_template_name = "search_template.rego"
        dataauthz_filename = "dataauthz.rego"
        manifest_filename = ".manifest"
        search_filename = "search.rego"
        template_path = "devops/gc/bootstrap-osdu-module/templates/"

        env = Environment(
            loader=FileSystemLoader(template_path),
            autoescape=select_autoescape()
        )
        dataauthz_template = env.get_template(dataauthz_template_name)
        manifest_template = env.get_template(manifest_template_name)
        search_template = env.get_template(search_template_name)
        dataauthz_render = dataauthz_template.render(dp_id=dp_id)
        manifest_render = manifest_template.render(dp_id=dp_id)
        search_render = search_template.render(dp_id=dp_id)

        with open(dataauthz_filename,"w") as f1:
            f1.write(dataauthz_render)
        with open(manifest_filename, "w") as f2:
            f2.write(manifest_render)
        with open(search_filename, "w") as f2:
            f2.write(search_render)
        with tarfile.open(tar_name, "w:gz") as tar_handle:
            tar_handle.add(os.path.abspath(dataauthz_filename), arcname=dataauthz_filename)
            tar_handle.add(os.path.abspath(manifest_filename), arcname=manifest_filename)
            tar_handle.add(os.path.abspath(search_filename), arcname=search_filename)

# Initialize class and upload bundles
if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument('--partition', required=True, type=str)
    args = parser.parse_args()
    BootstrapDataPartitionBundles.create_and_upload_dp_bundles(args.partition)
