import { Injectable } from '@angular/core'
import { ActivatedRouteSnapshot, CanActivate, Router, RouterStateSnapshot } from '@angular/router'
import { defer, iif, Observable, of } from 'rxjs'
import { catchError, map, mergeMap } from 'rxjs/operators'

import { AuthService } from './auth.service'

@Injectable()
export class AuthGuard implements CanActivate {
  constructor(
    private router: Router,
    private authService: AuthService,
  ) { }

  canActivate(route: ActivatedRouteSnapshot, state: RouterStateSnapshot): Observable<boolean> | Promise<boolean> | boolean {
    const checkAuth$ = of(this.authService.hasSession())

    return checkAuth$.pipe(
      // mergeMap(success =>
      //   iif(
      //     () => success,
      //     // this.authService.verifySession(),
      //     of(success),
      //   ),
      // ),
      map(success => {
        if (!success) {
          this.router.navigate(['/auth/login'], {
            queryParams: {
              redirectTo: state.url,
            },
          })
        }

        return success
      }),
      catchError(() => {
        this.router.navigate(['/auth/login'], {
          queryParams: {
            redirectTo: state.url,
          },
        })
        return of(false)
      }),
    )
  }
}
