import { Injectable } from '@angular/core'
import { HttpClient } from '@angular/common/http'
import { Observable } from 'rxjs'
import { map } from 'rxjs/internal/operators/map'
import { HttpParams } from '@angular/common/http'

export interface Policy {
  id: string
  raw: string
}

@Injectable()
export class PolicyService {
  private REST_API_SERVER = 'http://localhost:8080'
  private SERVICE_BASE_PATH = '/api/policy/v1'
  private REST_API_ENDPOINT = this.REST_API_SERVER + this.SERVICE_BASE_PATH

  constructor(private httpClient: HttpClient) {
  }

  getHealth() {
    return this.httpClient.get<any>(`${this.REST_API_ENDPOINT}/health`)
  }

  getConfig() {
    return this.httpClient.get<any>(`${this.REST_API_SERVER}/diag/config`)
  }

  getInfo() {
    return this.httpClient.get<any>(`${this.REST_API_ENDPOINT}/info`)
  }

  getDiagPolicies() {
    return this.httpClient.get<any>(`${this.REST_API_SERVER}/diag/policies`)
  }

  getPolicies(): Observable<Policy[]> {
    return this.httpClient.get<any>(`${this.REST_API_ENDPOINT}/policies`).pipe(
      map(data => data.result)
    )
  }

  getPolicy(dataPartition: string, policyId: string) {
    return this.httpClient.get<any>(`${this.REST_API_ENDPOINT}/policies/osdu/partition/${dataPartition}/${policyId}`).pipe(
      map(data => {
        return {
          PolicyId: data.result.id,
          RAW: data.result.raw
        }
      })
    );
  }

  getInstancePolicy(dataPartition: string, policyId: string) {
    return this.httpClient.get<any>(`${this.REST_API_ENDPOINT}/policies/osdu/instance/${policyId}`).pipe(
      map(data => {
        return {
          PolicyId: data.result.id,
          RAW: data.result.raw
        }
      })
    );
  }

  getPolicyFull(dataPartition: string, policyId: string) {
    return this.httpClient.get<any>(`${this.REST_API_ENDPOINT}/policies/osdu/partition/${dataPartition}/${policyId}`)
  }

  evaluateQuery(policyId: string, fileData: string, includeAuth: boolean) {
    const form = new FormData()
    //const text = await new Response(fileData).text()
    form.append('file', new Blob([fileData]), 'query.json' )

    return this.httpClient.post<any>(`${this.REST_API_ENDPOINT}/evaluations/query`, form, {
      params: {
        policy_id: policyId,
        include_auth: includeAuth ? 'true' : 'false',
      },
    })
  }

  text2Binary(str: string) {
    return str.split('').map(function (char) {
        return char.charCodeAt(0).toString(2);
    }).join(' ');
  }
}
